# GitLab CI Java Example

Please refer to the [official documentation](https://docs.gitlab.com/ce/ci/yaml/README.html)
to view all configuration options available.

[![pipeline status](https://gitlab.fi.muni.cz/unix/ci-examples/badges/java-maven/pipeline.svg)](https://gitlab.fi.muni.cz/unix/ci-examples/commits/java-maven)

This project contains a simple Java library that provides an `Algebra`
class with a `factorial` static function.
Tests are written using JUnit framework.

Let's break down the contents of `.gitlab-ci.yml`:

```yml
image: maven:3-jdk-8
```

The first line declares that the runner should use official [`maven`](https://hub.docker.com/_/maven/)
image with Maven 3 and OpenJDK 8.

```yml
stages:
  - build
```

The whole pipeline has only a single stage called `build`.

```yml
build:
  stage: build
```

The second line seems superfluous, but in general the stages do not need
to be called `build` or `test` and there can be more than one.
The `stage: build` declaration merely informs the runner that this stage
is actually part of the build *phase*.

```yml
  tags:
    - shared-fi
```

`gitlab-ci.fi.muni.cz` will only run jobs that have tag `shared-fi`.

```yml
  script:
    - mvn dependency:resolve --quiet
    - mvn compile package
```

Finally, the `script` section contains a list of commands that shall be
performed inside the repository once the runner starts.
These *should* be executed inside a single shell instance so that
`cd` and similar commands should work as expected, but unfortunately
this is not specified in the official documentation.
